package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````I1<``#0```"LL0````0`!30`(``)
M`"@`&P`:``$``'#(G@``R)X``,B>```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#4G@``U)X```4```````$`
M`0```("M``"`K0$`@*T!`,`"``#8$@``!@```````0`"````B*T``(BM`0"(
MK0$`*`$``"@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D@*T`
M`("M`0"`K0$`@`(``(`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50`F>![%_T@8Q\EC2F[#*HL/;U*8&!$```!0````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%````!1````50``
M`%H```!;````8@```&,```!D````9@```&<`````````:0```&H```!K````
M;0```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M``````````````````````#`$@````````,`"P```````+`!```````#`!8`
MN0(`````````````$@```&<#`````````````!(````[`P`````````````B
M````@`,`````````````$0```"L$`````````````!(````1````````````
M```@````*@(`````````````$@````T#`````````````!(```!8`P``````
M```````2````$0$`````````````$@```)X#`````````````!$```"T````
M```````````2````U`(`````````````$@```(,!`````````````!(```#`
M`@`````````````2````A```````````````$@````P!`````````````!(`
M``#;`@`````````````2````:@(`````````````$@```#D"````````````
M`!(```![`@`````````````2````B`(`````````````$@````$!````````
M`````!$```!G`0`````````````2````XP``````````````$0```#4!````
M`````````!(````4`P`````````````2````!@,`````````````$0```!T#
M`````````````!(```#"```````````````2````L0$`````````````$@``
M`"("`````````````!(```">`0`````````````2````]`(`````````````
M$@````H"`````````````!(```"J`0`````````````2````;@,`````````
M````$@```$,!`````````````!(````M```````````````@````G0(`````
M````````$@```$L"`````````````!(```"K`@`````````````2````O`$`
M````````````$0```&0``````````````!(````J`P`````````````2````
MDP``````````````$@```!$"`````````````!(```!*`P`````````````2
M````GP``````````````$@```%@"`````````````!(```!<`0``````````
M```2````@@(`````````````$@```+("`````````````!(````B`0``````
M```````2````5@``````````````$@```!8!`````````````!(```"3`0``
M```````````2````Q@(`````````````$@```/```````````````!(```"6
M`@`````````````2````8`,`````````````$@```*0"`````````````!(`
M``!U`0`````````````2````<P``````````````$@```($#````````````
M`"$````Q`P`````````````2````U```````````````$@```%,!````````
M`````!(````\```````````````@````@@,`````````````$0```/P"````
M`````````!(```!0`@`````````````2````D`(`````````````$@````0"
M`````````````!(```#I`@`````````````2````80(`````````````$@``
M`/`!`````````````!(```#@`P``6,`!```````0`!<`-`0``'%>``!0````
M$@`-``($```@7P```````!(`#@!9!```V5,``.`'```2``T`>P,``/$5``"T
M`0``$@`-``@$``#-3@``!````!(`#0#1`P``0+`!```````0`!<`QP0``-%.
M``"T`0``$@`-`,$$``#`$@```````!(`"P#T!```N5L``+@"```2``T`Q0,`
M`$"P`0``````$``7`$`$``"%4```%@```!(`#0!S!```*%\```0````1``\`
M\P,``%C``0``````$``7`.L#``!8P`$``````!``%P"_!```M4T``#@````2
M``T`U`0``#U3``"<````$@`-`.8$``#-4@``8````!(`#0!F!````+`!````
M```0`!8`300``)U0``"L````$@`-`+X#``!`L`$``````!``%@"H!```/+`!
M``0````1`!8`^`,``!U?```"````$@`-`)@$``#A7@``/````!(`#0!L!```
MI1<````````2``T`:`0```"P`0``````(``6`!D$```M4P``$````!(`#0#?
M`P``6,`!```````0`!<`@@0``#E.``"4````$@`-`+($``!)40``A`$``!(`
M#0``;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E
M<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P
M97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T
M<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3
M`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`
M<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M
M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O
M+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F
M;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P
M:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT
M9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER
M`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H
M:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C
M:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?
M96YV:7)O;@!L9"UL:6YU>"UA<FUH9BYS;RXS`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S7W-T87)T
M7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?9FEN:0!P
M87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D
M:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N
M=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0`````
M`````@`"``(``@`"`````P`"``(``@`$`````@````(```````(``@`"``(`
M`@````````````(``@`"```````#`````@`#``(``@```````@`"``(`````
M``(````#``(````"`````@`"`````````````@````(``@`"```````"``(`
M`````````@`"``(``@`#``(``@`#``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0"*`P``
M$````"`````4:6D-```$``H%`````````0`!`.`!```0````(````!1I:0T`
M``,`"@4````````!``$`+P(``!``````````%&EI#0```@`*!0```````("M
M`0`7````A*T!`!<```"\KP$`%P```."O`0`7````Z*\!`!<```#PKP$`%P``
M``2P`0`7````#+`!`!<````0L`$`%P```!BP`0`7````'+`!`!<````@L`$`
M%P```"2P`0`7````*+`!`!<````PL`$`%P```#2P`0`7````/+`!`!<```#`
MKP$`%04``,2O`0`5"```R*\!`!4-``#,KP$`%1```-"O`0`5&0``U*\!`!4;
M``#8KP$`%1X``-RO`0`5*0``Y*\!`!4M``#LKP$`%3@``/2O`0`50@``^*\!
M`!5'``#\KP$`%4@``+RN`0`6`P``P*X!`!8$``#$K@$`%@4``,BN`0`6!P``
MS*X!`!8)``#0K@$`%@H``-2N`0`6"P``V*X!`!8,``#<K@$`%@X``."N`0`6
M#P``Y*X!`!81``#HK@$`%A(``.RN`0`6$P``\*X!`!84``#TK@$`%A4``/BN
M`0`6%@``_*X!`!87````KP$`%A@```2O`0`6&@``"*\!`!8<```,KP$`%AT`
M`!"O`0`6'P``%*\!`!8@```8KP$`%B$``!RO`0`6(@``(*\!`!8C```DKP$`
M%B0``"BO`0`6)0``+*\!`!8F```PKP$`%B<``#2O`0`6*```.*\!`!8I```\
MKP$`%BH``$"O`0`6*P``1*\!`!8L``!(KP$`%BX``$RO`0`6+P``4*\!`!8P
M``!4KP$`%C$``%BO`0`6,@``7*\!`!8S``!@KP$`%C0``&2O`0`6-0``:*\!
M`!8V``!LKP$`%C<``'"O`0`6.0``=*\!`!8Z``!XKP$`%CL``'RO`0`6/```
M@*\!`!8]``"$KP$`%CX``(BO`0`6/P``C*\!`!9```"0KP$`%D$``)2O`0`6
M1```F*\!`!9%``"<KP$`%D8``*"O`0`620``I*\!`!9*``"HKP$`%DL``*RO
M`0`63```L*\!`!9-``"TKP$`%DX``+BO`0`63P``"$`MZ4@!`.L(@+WH!.`M
MY03@G^4.X(_@"/"^Y=2;`0``QH_B&<J,XM3[O.4`QH_B&<J,XLS[O.4`QH_B
M&<J,XL3[O.4`QH_B&<J,XKS[O.4`QH_B&<J,XK3[O.4`QH_B&<J,XJS[O.4`
MQH_B&<J,XJ3[O.4`QH_B&<J,XIS[O.4`QH_B&<J,XI3[O.4`QH_B&<J,XHS[
MO.4`QH_B&<J,XH3[O.4`QH_B&<J,XGS[O.4`QH_B&<J,XG3[O.4`QH_B&<J,
MXFS[O.4`QH_B&<J,XF3[O.5X1\!&`,:/XAG*C.)8^[SE`,:/XAG*C.)0^[SE
M`,:/XAG*C.)(^[SE`,:/XAG*C.)`^[SE`,:/XAG*C.(X^[SE`,:/XAG*C.(P
M^[SE`,:/XAG*C.(H^[SE`,:/XAG*C.(@^[SE`,:/XAG*C.(8^[SE`,:/XAG*
MC.(0^[SE`,:/XAG*C.((^[SE`,:/XAG*C.(`^[SE`,:/XAG*C.+X^KSE`,:/
MXAG*C.+P^KSE`,:/XAG*C.+H^KSE`,:/XAG*C.+@^KSE`,:/XAG*C.+8^KSE
M`,:/XAG*C.+0^KSE`,:/XAG*C.+(^KSE`,:/XAG*C.+`^KSE`,:/XAG*C.*X
M^KSE`,:/XAG*C.*P^KSE`,:/XAG*C.*H^KSE`,:/XAG*C.*@^KSE`,:/XAG*
MC.*8^KSE`,:/XAG*C.*0^KSE>$?`1@#&C^(9RHSBA/J\Y7A'P$8`QH_B&<J,
MXGCZO.4`QH_B&<J,XG#ZO.4`QH_B&<J,XFCZO.4`QH_B&<J,XF#ZO.4`QH_B
M&<J,XECZO.4`QH_B&<J,XE#ZO.4`QH_B&<J,XDCZO.4`QH_B&<J,XD#ZO.4`
MQH_B&<J,XCCZO.4`QH_B&<J,XC#ZO.4`QH_B&<J,XBCZO.4`QH_B&<J,XB#Z
MO.4`QH_B&<J,XACZO.4`QH_B&<J,XA#ZO.4`QH_B&<J,X@CZO.4`QH_B&<J,
MX@#ZO.4`QH_B&<J,XOCYO.4`QH_B&<J,XO#YO.4`QH_B&<J,XNCYO.4`QH_B
M&<J,XN#YO.4`QH_B&<J,XMCYO.4`QH_B&<J,XM#YO.4`````\+6)L%A,64M\
M1`60!)$%J`.2!*GF6`.J,V@'D__W/.]32E1+HEC@6!%&!/!1_%)+XU@?>``O
M:=!02^58*&C_]]COD/@.-`)&*&A#\`(#@O@.-/_WSN\%FP4SL_&`3Y#X#B1"
M\`$"@/@.)&G2F``$)__WUNY"2@2=>D1"2Q%H>T1!2BQH>D1#8,#I`A(_2P6:
M>T0$8`$JP^D!<`K=ZQD`\0P!!>N"!5/X!$NK0D'X!$_YT3=/`O&`00`D`S%_
M1`"40/@A0`-&/6D#,C))*$9Y1/_W+N\$1G"S+TT&KWU$*&G_]W3N+4@Y1GA$
M`_`]^>BQ*TM[1!AI__=$[O_W#N\'FC-H($::0BK1";#PO?_W?.XD2GI$$&$@
ML__W+.X72^58*&C_]V;O@/B!=H?GZ&AHL03PIOO<YSAI__<P[P1&R^<92QI(
MX5AX1/_WQ.X82#E&>$0#\`GYZ&``*,G0Z.?_]QSN`2#_]XSNM)@!`!@!```\
M`0``1`$``"0!```@`0``T)D!`/)+``#P2P``P)D!`)29`0`K-P``=)D!`$1)
M``!>F0$`/ID!`#0!``!B2@``>$@``$_P``M/\``.`KQJ1@2T`;3?^"2@"*.:
M1-_X(,!:^`S`3?@$S09+6O@#,`9(6O@``/_W-.[_]^KNU)8!``P!```X`0``
M0`$``!0PG^44()_E`S"/X`(@D^<``%+C'O\O`1/__^JTE@$`+`$```9(!TMX
M1`=*>T2#0GI$`]`%2]-8`[$81W!'`+\HF`$`))@!`)"6`0`4`0``"$@)2WA$
M"4I[1!D:>D2)$`'KT7%)$`/0!4O36`.Q&$=P1P"__)<!`/B7`0!DE@$`2`$`
M``BU"DL*2GM$>D0;>&NY"4O36".Q"$M[1!AH__<V[?_WO_\&2P$B>T0:<`B]
MQI<!`#26`0`0`0``>I<!`*:7`0#$YP"_`````-_X?#X`\4`,W_AX+BWI\$][
M1*WU/WT`\8`(#?%P"D_P``X:D)M84$8;DQMHO9-<^`0<`"5<^`A\#/$(#.!%
MP/@$X$_J$2)/ZA%F3^H!(P+T?T0`DT3J!@(!ED7J#@/=Z0!%3^H!84+J`0)/
M\``%!/1_!$/J!0-"Z@0"/[K`Z0(C`/$0`$#X$'S1T0WQ:`P*]?Q^S?@`H&1&
M_.D"B=3I$B,`(=3I'&?4Z09%@NH&"H/J!PM21F)`B.H"!%M&:T`B&8GJ`P7@
M#_1%0.I%`$#J`@0@1LSI(`'>T1J;`"0`)=WX`*`A1BI&T^D`9\WI`!+-Z082
M\@X`DM/I!!)]`=/I`KQ%ZM9EVND`B70!S>D$$M/I!@'3Z0@C`)7-Z0)GS>D2
M(_L.`9,/]DA3T^D`(\WI"@$2ZP@"S>D6O)!&W>D$(T)`%D;=Z0`C`",B0]WI
M$D44ZP@$H$9<1C1`&.L"""9&9$:D!P>47$8'FJ`(W>D*14+JFP('DG1`0.J,
M<"9&7$:B!P:2W>D&16)&D0@6ZP@&!$,-0T_P``RS1B=&J$8X1LWI"'A/ZDP6
M`"0`(<WI`#3:Z0(C3^K<90&6W>D$9\WI!@$!F8;J``A!ZMMA`9$,1@_VH$'1
MZ0`!@!@"1MWI`@%/ZDL1`)$`Z@@`@$;=Z0H!ANH(!MWI`HF`&`)&W>D``2!#
M*4/-Z0`!D!D`F4I&EP=/\``)0AC=Z0(!1^J8!T_J21Z01H8'C0A&Z@<"1^H%
M`]KI!$5.ZMAN%D8?1MWI""-P1LWI#&=/ZMEA<D#-^`3@3^I('LWX`.`61@;J
M"P(/]A!'U^D`9T_JG`,V&31&W>D&9U9`,D;=Z01G-ADT1MWI`&<&0P]#S>D`
M9Z`8`)E/ZHQW1^J;!P`B1!@`(4?J`PP`(R!&S>D`(]KI!D5+`0&33^J+=@_V
MO#/3Z0`C1NH'"\WI"+P2&6M!S>D.(P&;W>D(14/JT&,!DYM&W>D,(Q9&9D`?
M1F]``",U1LWI#",%Z@@"!^H)`]WI#D7=Z09GI!E]0=WI#&=60%]`3^J9`S)&
M1@$`EJ881>L'!\WI!F?=Z0!G3^J)=0`G1>J8!4;J"P9/ZHATW>D&O+Q&1>H#
M"$3J!0<`(P`DS>D&-&-&&^L&"UL!!Y,^1@_V&#/3Z0`C1T8'FT_JVVC-Z0"\
M2.I,&$/JVV/=Z0B\VND(14_P``S-Z0YG`"6D&%I&<D#=Z0QG`D#-Z0R\-AD'
MDXL(3_``"31&7D;=Z0"\5D`R1EY&%.L""W8!!I8`)LWI"%;=Z09GC`<)E$_J
M21=&Z@@&&^L&!`F>H$9&ZI`.A`?-^"3@")1V1MWI"`%'ZMAGVND*11E##_:`
M(]/I`",P0P:7$AE/ZD@6:T'-Z0@CW>D.(P`ES>D.`2E&`"<41D1`$$:C1MWI
M`#3=Z0A%"^H#"UI&W>D,O,WI$`%/ZMEL%.L+!,WX',"`Z@(+%.L+"]WI!D4T
M0R9&`9RA!P"<H@@;ZP8$W>D`O"9&7$9!ZIL!H`=D1D+JC'*C"$#J`@O:Z0Q%
M0>H##`_V]!+2Z0`2S>D(O'L!"1E#ZM9C:D'-Z082W>D.`0`AW>D(14_P``P!
MD\WI#`$"1MWI$`%B0-WI!D4"Z@@"S>D&9R08W>D,`7$!`)'=Z0!G4$!/ZHEQ
M'D,"1J`80>J8`8093^J9`T_JB'``(J-&0>H#"-KI#D4`(\WI`"-/ZDP3`9-`
MZ@$'#_9L$]/I`"-!1CA&W>D(9Q(9S>D(`6M!%$8R1AU&`9M"0$/JVV,!DYA&
M.T9+0-WI#`$`)\WI#F<`&=WI!F=I001&'T`-1MWI#@$60'E`<$`@&`M&3^I+
M$0"11>L#`=WI`&?-Z0P!1NH(!MWI!HE,1D_P``FA!]WI#$5!ZI@!3^K9;J09
MW>D&5LWX!."@1K,(J`=!Z@,'VND010_VU`/3Z0`C0.H!!CE&3^I)%Q(9,$9K
M0=WI"$7-Z08C"D;-Z1`!54#=Z0@2=$`%Z@P#`")'ZMAG`)?-Z0P2!.H+`MWI
M#@%/ZD@6W>D&10`G)!A-0=WI#`%00%E`3^J<`P)&H!A%ZP$!W>D`1<WI!@%/
MZHQQ-$-!ZIL!0>H##``B)D;=Z09%`"/-Z08CI!E[`0>33^J+<"9&#_8\`]/I
M`"/:Z1)%0.H!"\WI"+Q/\``,$AG-Z0!G:T'-Z10C!YL`)=WI$!)#ZM9CW>D(
M9P>3#$9T0"9&#$;=Z0P!!NH(`LWI#D7=Z11%W>D`9R08W>D.`7$!4$`&D4_J
MB7'=Z09G`D:@&$'JF`$>0T_JF0.$&4_JB'!`Z@$'0>H#"*-&#_*X<M+I`!+:
MZ11%3^I,$T/JVV,^1@D9!Y-J04=&#$;=Z0@!%4:81LWI"&<"1@M&`"'-Z0P!
MW>D.`7)`>T#=Z0!G`!EI01]`!$860`U&W>D,`7E`<$`@&`M&3^I+$0:11>L#
M`=WI!F?-Z0X!1NH(!MWI`(E,1D_P``FA!]WI#D5!ZI@!3^K9;J09W>D`5LWX
M!."@1K,(J`=!Z@,'VND610_R&'/3Z0`C0.H!!CE&3^I)%Q(9,$9K0=WI"$7-
MZ08C"D;-Z1`!54#=Z0@2=$`%Z@P#`")'ZMAG`)?-Z0X2!.H+`MWI#`%/ZD@6
MW>D&10`G)!A-0=WI#@%00%E`3^J<`P)&H!A%ZP$!W>D`1<WI!@%/ZHQQ-$-!
MZIL!3^J+<$'J`PPF1MWI!D5`Z@$+`"*D&<WI"+P`(\WI!B,F1GL!VND814_P
M``P'DP_R<&/3Z0`CS>D`9Q(9:T'-Z10C!YL`)=WI$!)#ZM9CW>D(9P>3#$9T
M0"9&#$8&Z@@"S>D,1=WI#@'=Z0!GW>D41208W>D,`7$!!I'=Z09G4$!/ZHEQ
M'D,"1J`80>J8`8093^J9`T_JB'!!Z@,(HT9`Z@$'VND:14_J3!,/\O12TND`
M$D/JVV,^1@>3"1E'1FI!F$8,1MWI"`$51LWI"&<"1@M&`"'-Z0X!W>D,`7)`
M>T#=Z0!G`!EI01]`!$860`U&W>D.`7E`<$`@&`M&3^I+$0:11>L#`=WI!F?-
MZ0P!1NH(!MWI`(E,1D_P``FA!]WI#$5!ZI@!3^K9;J09W>D`5J!&LPBH!T'J
M`P?:Z1Q%#_)@4]/I`"-`Z@$&.49/ZDD7$ADP1FM!W>D(1<WI!B-'ZMAGS>D0
M`0I&`)=50-WI"!)T0`7J#`,`(LWX!.!/ZD@6S>D,$@3J"P+=Z0X!`"?=Z09%
M)!A-0=WI#`%00%E`3^J<`P)&H!A%ZP$!W>D`1<WI!@%/ZHQQ-$-!ZIL!0>H#
M#``B)D;=Z09%`"/-Z08CI!E[`0>33^J+<"9&#_+$0]/I`"/:Z1Y%0.H!"\WI
M"+Q/\``,$AG-Z0!G:T'-Z10C!YL`)=WI$!)#ZM9CW>D(9P>3#$9T0"9&#$8&
MZ@@"W>D,`<WI#D7=Z0!GW>D41208W>D.`7$!!I'=Z09G4$!/ZHEQ'D,"1J`8
M0>J8`8093^J9`T_JB'!!Z@,(HT9`Z@$'VND@14_J3!,/\CA"TND`$D/JVV,^
M1@>3"1E'1FI!F$8,1MWI"`$51LWI"&<"1@M&<D![0``AW>D`9\WI#`'=Z0X!
M'T`60``9:4$$1@U&W>D,`7E`<$`@&`M&3^I+$0:11>L#`=WI!F?-Z0X!1NH(
M!MWI`(E,1D_P``FA!]WI#D5!ZI@!3^K9;J09W>D`5LWX!."@1K,(J`=!Z@,'
MVNDB1>BCT^D`(T#J`08Y1D_J21<2&3!&:T'=Z0A%S>D0(PI&S>D.`55`W>D(
M$G1`!>H,`P`B1^K89P"7S>D&$@3J"P+=Z0P!3^I(%MWI$$4`)R0834'=Z08!
M4$!90$_JG`,"1J`81>L!`=WI`$7-Z0@!3^J,<31#0>J;`4'J`PP`(B9&W>D(
M10`CS>D`(Z09>P$!DT_JBW`F1L*CT^D`(]KI)$5`Z@$+S>D(O!(9W>D.O&M!
MS>D0(P&;W>D(15I&0^K68P&38D`81F-&3_``#&M`S>D,O`+J"`+=Z0:\`^H)
M`]WI$$44ZPL$1>L,!=WI#+R+Z@(+C.H##!OK!`)/ZD83`)-,ZP4#W>D`O``D
M`"5+Z@`+*48@1LWI``$2ZPL`3^J8`4_JB74`D4/Q``%%ZI@%3^J9`P"5`9,*
M1D_JB'0!1H!&S>D0$MWI``%/\``)VNDF(R!#*4/-Z08!`"``(<WI``%/ZMAA
M`)&.H='I``%/ZDD51>K890"5@!A/ZD@464'=Z0@CS>D4`=WI!@&#Z@$,@NH`
M"P`CW>D4`<WI#B,+Z@8"#.H'`]WI#+P0ZPL`0>L,`=WI#KR+Z@(+C.H##!OK
M``)/ZMEC`9-,ZP$#W>D`O+D(3_``#$OJ!`L2ZPL$0_$`!;L'0^J6`P&3HT;-
MZ11%&$:S!P"3W>D`1=KI*",-0P1#+D8@1C%&W>D&5LWI"`%E0"Y&9:75Z0!%
MI!A=02!&W>D0-"E&W>D.17-`)!A-04_J3!%!ZMMA(D8!D1Y&#$9/ZDL1`)&0
M&=WI`"-%\0`!3^J)=4_JF0,B0T7JF`6&&$_JB'1/\``(0?$`!T7J`PE!1D3J
M!0C=Z0A%S>D,B3!&A.H(!-WI%(G:Z2HC3^J,=8CJ!`C-Z0YG3P%%ZIL%1$8/
M\@@9V>D`B4?JUF<`EQCK`@@&FDGK`PEV`1CK`@))\0`#$NL$"$/Q``G+#@&3
M3^J+=-WI`"-/ZIP#3_``##)#&.L"!D7J`PA)\0`'S>D09T3J!0=#1MKI+$6S
M1CI&S>D&(RJCT^D`(]WI#(D2&8CJ!PC=Z0YG%$8(FFM!ANH(!J(83^I,%$3J
MVV2P1@&40_$``R9&3^I+%`"4$NL(!$/Q``7=Z0`CCP>+"#)#1^J0!Q3K`@A/
MZH!V1?$`"0`A1$9`1DU&S>D.14?J`P5&Z@<$VNDN(R=&J$;=Z09%3^J,=<WI
M"'A%ZIL%#_(@"=GI`(E\0-WI$&=/`1CK`@@,F@W@K_,`@)EY@EH`````H>O9
M;@````#DE0$`&`$``(;J!`9)ZP,)&.L"`D?JT&<T1DGQ``,2ZP0(`)=#\0`)
MRPX!DT8!W>D`(T_JBW1/ZIP#3_``##)#&.L"!D3J!0A)\0`'1>H#"<WI$&="
M1DM&W>D(B=KI,$6S1LWI#".(Z@((#_;,8]/I`"/=Z0YGCP<2&4?JD`=K08;J
M"`841@::L$:B&$_J3!1$ZMMD0_$``P&4)D9/ZDL4`)02ZP@$0_$`!=WI`".+
M"``A,D.&!Q3K`@A%\0`)W>D,14!&S>D.B4;J!PA'Z@,)A.H(!-KI,B/-Z0:)
M3^J,=0_V5&G9Z0")1>J;!=WI$&=/`1CK`@@(FH;J!`9)ZP,)&.L"`D?JT&<T
M1DGQ``,2ZP0(`)=#\0`)RPX!DT8!W>D`(T_JBW1/ZIP#3_``##)#&.L"!D7J
M`PA)\0`'S>D09T3J!0=#1MKI-$6S1CI&S>D((P_VY%/3Z0`CW>D&B1(9B.H'
M"-WI#F<41@R::T&&Z@@&HAA/ZDP41.K;9+!&0_$``P&4)D9/ZDL4`)02ZP@$
M0_$`!=WI`"./!XL(,D-'ZI`'%.L""$_J@'9%\0`)`"%$1D!&34;-Z0Y%1^H#
M!4;J!P3:Z38C)T:H1MWI"$5/ZHQUS>D,>$7JFP4/]EQ9V>D`B7Q`W>D09T\!
M&.L""`::ANH$!DGK`PD8ZP("1^K09S1&2?$``Q+K!`@`ET/Q``G+#@&31@'=
MZ0`C3^J+=$_JG`-/\``,,D,8ZP(&1.H%"$GQ``=%Z@,)0D;:Z3A%2T;=Z0R)
MS>D&([-&B.H""`_VZ$/3Z0`CS>D09Q(9W>D.9VM!CP<41@B:ANH(!D?JD`>B
M&$_J3!1$ZMMDL$8!E$/Q``,F1D_J2Q0`E!+K"`1#\0`%W>D`(XL(`"$R0X8'
M%.L""$;J!P1%\0`)1^H#!<WI#HE`1B=&J$;=Z09%3^J,==KI.B-%ZIL%S>D(
M>'Q`#_9H2=GI`(G=Z1!G3P$8ZP((#)J&Z@0&2>L#"1CK`@)'ZM!G-$9)\0`#
M$NL$"`"70_$`"<L.`9-/ZHMTW>D`(T_JG`-%Z@,,1.H%"T8!W>D(13)#S>D,
MO!CK`@:$Z@L$VND\(X7J#`4/]@!,W.D`O$GQ``?=Z0Z)&^L""P::3.L##(CJ
M!`@;ZP(#B>H%"61&1/$`!,WI#HD:1@`E(T8`),WI`$7T#@"4#IQ/ZD88S>D0
M9P`G$NL$"T_J1QE#\0`,2>K6:?L.S?@`D`&3C0?=Z0`C1>J0!80'BPA"Z@@"
M`"$;ZP((3/$`"<WI#HE`1D7J`PE$Z@4(VND^(TU&W>D0JT1&W>D,B<WI!D5/
MZD$;B.H$"`_V5#75Z0!%BNH("DOJT&ND&%U!T$8B1@B<`"-/ZD`:%!E/\``"
M1?$`!<WI`",4ZP@"3^K08URL`)-%\0`#S?@`L)!&O0>91M3I`#1%ZI8%S>D4
M-,L.`9.T!]WI`".["$+J"@)/\``*5T9%Z@,*&.L""$GQ``G-Z1")1.H%"51&
MW>D&JT9&2T;-Z0@TBNH)"MWI%"/=Z0Y%3^J!>=!&#_:X*]OI`*N$Z@@$2>J0
M"1KK`@H,FDOK`PN@1@`C`"3-Z0`T>P$!DQKK`@-+\0`$FD8!FZ-&]`Y#ZM9C
M`9-S`0"3W>D`(T3J1Q0:ZP@*S?@`D$+J!`)+\0`+&NL"!$_JD0,!DTOQ``4B
M1LWI%$7=Z0!%3^J`>%ZI`"-$Z@@$1>H)!='I``%/ZD,;H$:I1MWI"$5+ZM)K
MS>D,B4_J0AJ$Z@@$#_84*=GI`(F]!QCK``@&F$GK`0G-Z0")W>D0B47JE@6$
M1MWI``&(Z@0(S?@`L!#K#``-]<!\0?$``41&$.L$"$_JAG1!\0`)V0X!D=WI
M``&Y"$#J"@`8ZP`*")A)\0`+T4;:1LWI$)I/\``*1>H!"U=&1.H%"MWI#$5.
M1LWI#JMY`=SI`(F%Z@L%#_:,'-SI`+R$Z@H$0>K680&1&^L("T_JDP%,ZPD,
MV$;=Z12KX48-]<1\BNH$"HOJ!0O-Z0:K=`$`E!CK``H&G$GQ``OP#AKK!`A`
MZD<02_$`"=WI`*M*Z@`*&.L*!$GQ``6@1IP'1.J2!`>4J4;-Z12)($:4!P:4
M0D;=Z09%`"/<Z0")3^I#&P1##4-+ZM)KS?@`L"!&*4;=Z0Y%3^I"&LWI"`&]
M!T1`#_;D`='I``%%ZI8%$.L(`$'K"0&`1HE&W>D0`6!`!$8,F!CK``!)\0`!
M$.L$"$'Q``G9#@&1M`?=Z0`!N0A`Z@H`&.L`"TGQ``Q>1ME&XD8-]<A\1.H%
M"\WI$)K<Z0")1>H!#-WI"$5/\``*5T;-Z0R\A.H+!`_V;`O;Z0"KA>H,!0Z8
M&NL("D_J1Q%+ZPD+0>K68=!&`9'91MWI%*N9"`WUS'R*Z@0*B^H%"\WI!JMT
M`0"4&.L`"@:<2?$`"_`.&NL$"$#J1Q!+\0`)W>D`JTKJ``H8ZPH$2?$`!=SI
M`(FB1IP'1.J2!`>4JT;-Z12K($:4!P:43_``"]WI!D5;1E)&3^I#&P1##4-+
MZM)KS?@`L"!&*4;=Z0Q%3^I"&LWI#@&]!T1`#_*\<='I``$-]=!\1>J6!1#K
M"`!!ZPD!@$:)1MWI$`%@0`1&")@8ZP``2?$``1#K!`A!\0`)V0X!D;0'W>D`
M`;D(0.H*`!CK``I)\0`+T4;:1LWI")I/\``*3D971MSI`(E$Z@4*1>H!"P_R
M5''1Z0`!5$9=1A#K"`#=Z0ZK0>L)`=WI%(F*Z@0*S>D``8CJ"@@,F,WI$$5]
M`<)&W>D`B47JUF7Y#ACK``@`E1CK"@`!D70!G0B`1MWI``%/ZH-[:JM+ZI(+
M($-/ZH)Z`"'3Z0`C&.L`"(E&`"``(<WI``%*Z@L`2^H%`=WI$$7&1H)&BT;-
MZ0RK2$8/\L1LW.D`O$`!`9"$Z@H$&^L""T)&TPX!FEA&0^I)$P:3`"641@Z:
M3.K8;,WX!,#=Z0B\@!A"1LWI%(F+Z@0+4@$0ZPL``))*1MWI`+S3#@>3!$;=
MZ08!3^J'>4_JAGA`Z@L`2>J6"208S>D`14CJ"06["$GJ`P9LJ:M&W>D,1;1&
MS>D,O$3J"PE%Z@8*T>D``0`E2D931ME&3_``"LWI")I/\``,#_(H:MKI`)K=
MZ12KS>D.11GK``E41A1`$)I=1AU``)L9ZP((S>D41=WI"!(`(MWI#D7;#D_P
M``D,0``AS>D&$@:3W>D4(VZK!IDB0]WI`$42ZP@`6D9!ZD41!I'I#@>1@$;=
MZ08!9@&5!S!#1>J:!1CK``)01H0'T^D``9!&6D9$Z@4*EPC=Z0PC1>H'"\WI
M$*M/ZDD70NH*`D/J"P/31LWI#+P/\H1;V^D`JT?JV&?=Z0"\3^I(%AKK``K=
MZ0A%"^H""]WI#!)01@SJ`PS-Z12\#$#=Z0ZK3^K88P`A`"+-Z0823^K980:3
M&NL`"MWI%",-]0!\!I<'D2)#W>D&`1KK`@H!FS!#&NL``MWI`*N=!P";1>J:
M!9)&W>D`$IX(<*M&ZHMV3_``"\WI`*N,!Y<(T^D``43J!@)%Z@<#W>D(JQ1&
M3^J9!QU&W>D0(\WI$$5/\``+(D,K0P`ES>D.10_RR$75Z0!%`^H)!208($8"
MZ@@$W>D.$AKK``K-Z11%`"+=Z0PT"T``(<WI!A+=Z0`!'$;##@:3W>D4(PU&
M!IERJR)#!$82ZPH`0>I%$0:1Z0X'D0)&W>D&`68!3^J)=4_JB'0P0T7JF`5$
MZ@4(1>H'"1(8#_)41=7I`$73Z0`!3^I+%Y)&W>D0(R08S>D0B4U!0NH(`B!&
M0^H)`RE&W>D`14_P``G-Z0B)%$`=0,WI%$5'ZMIGW>D,-$_J2A8;&$Q!W>D(
M$IA&3^K:8Z%&W>D.10Q`%4``(0`BS>D&$D_JVV$&D]WI%",'D2)#*T,2ZP@`
M!I=#ZPD!W>D`B<WI#`'=Z08!2D9/\``)E0?=Z0PC,$-TJQ(8W>D``47JF`60
M1H0'CPA$Z@4"T^D``47J!P-/ZDD7%$9'ZMAG'4;=Z1`CS>D&14_J2!8B0RM#
M`"7-Z0Q%W:75Z0!%`^H+!208($8"Z@H$S>D01=WI#D7=Z0PC`",D&"!&W>D(
M14_JBW440``BS>D`(T_JV&,`DT7JF@7=Z1`C=JL`ET_JFP<B0T_JV62`&`&4
M3^J*=$7J!PL"1MWI``%$Z@4*`"$P0UU&$AA41LWI$$5/ZID'$$;-Z0`!T^D`
M`=WI!B/=Z0BK3_``"R)#*T,`)<WI#D6WI=7I`$4#Z@D%)!@@1@+J"`3=Z0X2
M&NL`"LWI%$4`(MWI##0+0``AS>D&$MWI``$<1L,.!I/=Z10C#48&F7BK(D,$
M1A+K"@!!ZD41!I'I#@>1`D;=Z08!9@%/ZHEU3^J(=#!#1>J8!43J!0A%Z@<)
M$AB;I=7I`$73Z0`!3^I+%Y)&W>D0(R08S>D0B4U!0NH(`B!&0^H)`RE&W>D`
M14_P``G-Z0B)%$`=0,WI%$5'ZMIGW>D,-$_J2A8;&$Q!W>D($IA&3^K:8Z%&
MW>D.10Q`%4``(0`BS>D&$D_JVV$&D]WI%",'D2)#*T,2ZP@`!I=#ZPD!W>D`
MB<WI#`'=Z08!2D9/\``)E0?=Z0PC,$-ZJQ(8W>D``47JF`601H0'CPA$Z@4"
MT^D``47J!P-/ZDD7%$9'ZMAG'4;=Z1`CS>D&14_J2!8B0RM#`"7-Z0Q%9*75
MZ0!%`^H+!208($8"Z@H$S>D01=WI#D7=Z0PC`",D&"!&W>D(14_JBW440``B
MS>D`(T_JV&,`DT7JF@7=Z1`C?*L`ET_JFP<B0T_JV62`&`&43^J*=$7J!PL"
M1MWI``%$Z@4*`"$P0TFEU>D`11(8S>D0JT_JF0<01LWI``'3Z0`!W>D&(R08
M0NH*`D/J"P,#Z@D%($8"Z@@$S>D41=WI"$5/\``+S>D.JT_P``LD&-WI#A(`
M(J)&W>D,10Q``"'-Z082W>D``<,.!I/=Z10C#48&F7ZK(D,$1A+K"@!!ZD41
M!I'I#@>1`D;=Z08!9@%/ZHEU3^J(=#!#1>J8!43J!0@2&-/I``%%Z@<)W>D0
M-))&S>D0B4_J2Q=#Z@@#1.H)!$_P``G-Z0B)&D8C1MWI`$5'ZMIG#_)8"=GI
M`(E/ZDH6%$`=0,WI%$48ZP`(W>D,14GK`0G=Z0@!3^K:8Q3K"`1/\``"1>L)
M!:!&J4;=Z0Y%#4``(<WI!A($0`:33^K;80G@K_,`@*'KV6X`````W+P;CP``
M``#=Z10C!Y$B0RM#$NL(``:70^L)`=WI`(G-Z0P!W>D&`4I&3_``"94'W>D,
M(S!#1>J8!1(8W>D``0`FD$:$!X\(1.H%`D7J!P,`)<WI`%;=Z1!6'$831LWI
M!C0F0Q5#W.D``4_J210J1C-&W>D&5@`F-T8!E`WU`GPN1@_V[&75Z0!%`^H+
M!208($8"Z@H$S>D,1=WI#D5/ZHMU`9M%ZIH%)!C=Z0@!0^K88P&3W>D,(S!`
MS>D.9T_J2!8"0P"6%AE/ZMA@0.I)$$_JBG0R1MWI`&=/ZIL!`"<&0T7J`0.2
M&=SI`*L91@WU!'P61D3J!0+-Z0!G`"401MWI!B/-Z1`!!$8"0PM##_9@8='I
M``$#Z@D!S>D,14_JF0?=Z0!%$.L*`$_P``N"1@+J"`#-Z0`!($;=Z0@T*4;=
MZ0Q%#483ZPH#FD;=Z0XC`",B0!1&`"+-Z08CPPX&D]WI`",`(P:9(D,$1A+K
M"@!!ZD41!I'I#@>1`D;-Z0!%3^J)==WI!@%F`47JF`5/ZHAT1>H'"43J!0@P
M0]WI$%9'1A(8/4-&Z@D&DD;<Z0`!*D8`),WI!C0S1@_VM%;6Z0!6R$9/ZDL4
MS>D0>"T83_``"`>43D'-Z0AX*$;=Z0"),48-]09\1$9-1A1`'4#-Z0!%W>D.
M5@>;+1A.0=WI#`$L1D/JVF,U1MWI"&<'D]WI`",P0#E`3^I*%@)#!I8+0Q89
M0^L%!TI&S>D`9T_JVF#=Z09G0.I+$)4'W>D`(P9#S>D`B9(9W>D`9T7JF`5/
M\``)D$;=Z1`CM`>Y"$3J!09%Z@$'`"4R0S!&.48T1LWI$`'-Z0Y%.T/<Z0`!
M3^I)%P_V[$75Z0!%`^H+!4?JV&=/ZD@6`!D"Z@H$S>D&10WU"'S=Z0Q%W>D.
M(P`C)!@@1MWI"$5/ZHMU%$``(LWI`"-/ZMAC`)-%ZIH%W>D&(P`C`)=/ZIL'
M(D-/ZMED@!@!E$_JBG1%Z@<+`D;=Z0`!1.H%"@`D,$/=Z1!6$AC-Z08T1NH+
M!@`A$$;-Z0`!,T8`)MSI``%%Z@H%S>D0J[-&W>D`9RI&S>D,JPWU"GQ\`0>4
M#_8\1=7I`$4D&$U!($8"Z@@$*48#Z@D%S>D`1=WI"$4'FR0834'=Z0X!0^K6
M8P>3W>D`(P#J"@`!Z@L!LD8"0PM#\`YV`0:6%AF[1D#J1Q!#ZP4'S>D(9]WI
M!F=/ZHEUW>D((T7JF`4&0T_JB'1/ZID!DAE%Z@$'1.H%!MWI$$7<Z0"),$8T
M0SU#S>D`JY)&*T8B1@`E-$;-Z0A%.48/]J`UU>D`14_P``O-Z1`!3^I+%Q3K
M"`3=Z0X!1>L)!4?JVF>@1A#K"`"I1MWI`$5!ZPD!3^I*%A1`'4")1LWI%$7=
MZ0@23^K:8]WI#$4-]0Q\#$`50``A`"+-Z0823^K;80:3W>D4(P>1(D,K0Q`8
M!I=#ZPD!W>D`B<WI#@'=Z08!2D9/\``)E0?=Z0XC,$-%ZI@%$AC=Z0`!`":0
M1H0'CPA$Z@4"1>H'`P`ES>D`5MWI$%8<1A-&S>D&-"9#%4/<Z0`!3^I)%"I&
M,T;=Z096`"8!E#=&#?4.?"Y&#_;$)=7I`$4#Z@L%`9LD&,WI$&=#ZMAC`9,@
M1@+J"@3-Z0Y%W>D,14_JBW7=Z0XC1>J:!208W>D(`4_JFP$P0$_J2!8"0P"6
M%AE/ZMA@0.I)$$_JBG0R1MWI`&=%Z@$#W.D`JP9#`">2&1E&3_``"PWU$'P6
M1D3J!0+-Z0QG3^J9!Q!&W>D&(\WI%`$"0PM#`"'-Z0X!#_8L(='I``$#Z@D!
MW>D,11#K"@""1@+J"`#-Z08!($8I1MWI"$7=Z0XC`",4ZPH$HD;=Z1!%#484
M0``BS>D`(\,.`)/=Z08C`",`F2)#!$82ZPH`0>I%$0"1Z0X!D0)&3^J)==WI
M``%F`47JF`5/ZHAT1>H'"43J!0@P0]WI%%82&``DS>D&-$7J"`5&Z@D&DD9<
M1BI&,T9%1@`FS>D45F0!W>D,9P>4S>D`JSU&'4`T1A1`*T8`G=SI``$B1@_V
M<!O;Z0"K#?42?`><&NL`"D3JU64'E=WI$$5+ZP$+W>D.`13K"@1%ZPL%S>D(
M141&`"4@0"E`W>D`14#J`@I!Z@,+80$&D=WI"`'B#D+J11+K#A#K"@!/ZH=U
M0>L+`=WI!JM*Z@(*2^H#"\WI!JNR1E9&NT:R"`:>1>J:!4+JBW*&&4'Q``?-
MZ09G5D9?1K0'NPC=Z09G`"<Y1D7J`P='Z@D%W.D`O`_VR`K:Z0":,$9$Z@(&
M.T8;ZPD+1NH(!$_P``G-Z0Q%,D9<1LWI""/+1MWI#"-,ZPH,W>D`B4\!LD9'
MZM!G`NH(`@/J"0/=Z0Z)S>D8JQCK!`C=Z11%2>L,"<WI#(DT0`7J"P440QU#
MW>D,(T8!1^H&"!(9:T$2ZP@*0_$`"P`BT4;:1MWI`+S-Z0Z:3_``"LWI`)IC
M1I\'6T:>!V-&G0@-]11\`9M'ZIL'W.D`B4;J!PI'Z@4+#_88!]?I`&?=Z0A%
M#?46?,WI"*M/ZD,;`)L6ZP@&1^L)!]WI!HF$Z@H$C0A+ZM-K`"/-Z08CB.H$
M"`";`9I$1MWI%(G;#@:3`)L8ZP8(S?@8L$GK!PD8ZP0(3^J!=T_J0QI/ZM)C
M!Y-)\0`)S>D,B4?JD`?=Z0:)A@?<Z0`!1^H%#$CJ"@C=Z0RK&NL("DOQ``O1
M1MI&1NH'"]WI"%;(1LWI#+R%Z@L%W>D.O,WI$)I/\``*+D:+Z@8+#_)@==7I
M`$711EY&3^I*$]WI&*LD&$U!0^K88QKK!`H'DT_J2!,&DP";2^L%"QKK!@I/
MZH)U2_$`"T_JV&!%ZI,%`)M61E]&W>D&JT#J21"<!Y$(2NH`"D7J`0L6ZPH&
M#?48?$3J!0I'\0`'64;-Z0YG4$;<Z0`C#_+H:]OI`*L`)]WI#$4-]1I\&NL"
M"@B:2^L#"\WI!@%$0``A`"#-Z0`!>0%01@&164;=Z1"K@!@!FT'Q``&*Z@0*
M\@Y#ZM9CBT8!DU1&<0$`&0"12_$``=WI`*M"ZD<23^J9`TKJ`@H0ZPH$3^J(
M<$'Q``5/ZHEQ0>J8`=WI!HE`Z@$*0>H#"XCJ"@C<Z0`!S>D(JP_R5&O;Z0"K
MS>D010`E$.L*`$_J11-!ZPL!0^K48P&3BT;=Z0X2#)J!Z@@!@AB(1D_J1!$`
MD4OQ``.21N(.&NL(`-WI`*M"ZD420_$``4KJ`@J["!#K"@A/ZH9P0?$`";D'
M0>J6`=WI"&=`Z@$+0>H##,WI#+P-]1Q\3_``"LWI#HG<Z0`!T4:&Z@L&3^I*
M$P_RQ%O;Z0"K0^K88P&3#?4>?!#K"@!!ZPL!BT;=Z1`2!IIQ0((8#D9/ZD@1
M`)%+\0`#DD9/ZMAB&NL&`-WI`*M"ZDD20_$``4KJ`@JK"!#K"@9/ZH1P0?$`
M!ZD'0>J4`0_R9%O;Z0"K0.H!!$'J`P7-Z1!G`"<B1BM&W>D,1<WI!B-[`=SI
M``%40$/JUF,!DQ#K"@`-]2!\0>L+`8M&W>D.$@B:84""&`Q&3^I&$0"12_$`
M`Y)&\@X:ZP0`W>D`JT+J1Q)#\0`!2NH""D_JF0,0ZPH$3^J(<$'Q``5/ZHEQ
M0>J8`<WI#D5!Z@,*`"5`Z@$)`")11@`C#_+,2]OI`*M(1LWI`"-K`0&3W.D`
M(]WI!HD2ZPH"S>D(`4/K"P.(Z@`(DD;=Z1`2#)J;1H'J"`$!FQKK`@)#ZM1C
MB$8!DT_J1!$`D4OQ``.21N(.&NL(`-WI`*M"ZD420_$``4KJ`@J["!#K"@A/
MZH9P0?$`";D'0>J6`=WI"&=`Z@$+0>H##,WI#+P-]2)\3_``"LWI$(G<Z0`!
MT4:&Z@L&3^I*$P_R)$O;Z0"K0^K88P&3#?4D?!#K"@!!ZPL!BT;=Z0X2!IIQ
M0((8#D9/ZD@1`)%+\0`#DD9/ZMAB&NL&`-WI`*M"ZDD20_$``4KJ`@JK"!#K
M"@9/ZH1P0?$`!ZD'0>J4`0_RQ#O;Z0"K0.H!!$'J`P7<Z0`!#?4F?")&S>D.
M9Q#K"@!/\``'*T9!ZPL!W>D,1<WI!B-[`51`BT9#ZM9C`9/=Z1`2")IA0((8
M#$9/ZD81`)%+\0`#DD;R#AKK!`#=Z0"K0NI'$D/Q``%*Z@(*3^J9`Q#K"@1/
MZHAP0?$`!4_JB7%!ZI@!S>D014'J`PH`)4#J`0D`(E%&`",/\BP[V^D`JTA&
MS>D`(VL!`9/<Z0`CW>D&B1+K"@+-Z0@!0^L+`XCJ``B21MWI#A(,FIM&@>H(
M`0&;&NL"`D/JU&.(1@&33^I$$0"12_$``Y)&X@X:ZP@`W>D`JT+J11)#\0`!
M2NH""KL($.L*"$_JAG!!\0`)N0=!ZI8!W>D(9T#J`0M!Z@,,S>D,O`WU*'Q/
M\``*S>D.B=SI``'11H;J"P9/ZDH3#_*$*]OI`*M#ZMAC`9,-]2I\$.L*`$'K
M"P&+1MWI$!(&FG%`@A@.1D_J2!$`D4OQ``.21D_JV&(:ZP8`W>D`JT+J21)#
M\0`!2NH""JL($.L*!D_JA'!!\0`'J0=!ZI0!#_(D*]OI`*M`Z@$$0>H#!=SI
M``$-]2Q\(D8K1A#K"@#=Z0Q%0>L+`<WI!B-40,WI$&>+1MWI#A((F@`G84![
M`8(80^K68PQ&`9.21DOQ``-Q`1KK!```D4_JUF+=Z0"K0NI'$D/Q``%/ZID#
M2NH""@`B$.L*!$_JB'!!\0`%3^J)<4'JF`'-Z0Y%0>H#"@`E0.H!"0`C44;-
MZ0`C#_*(&]OI`*MK`0&32$;<Z0`CW>D&B1+K"@+-Z0@!0^L+`XCJ``B21MWI
M$!(,FIM&@>H(`0&;&NL"`D/JU&.(1@&33^I$$0"12_$``Y)&X@X:ZP@`W>D`
MJT+J11)#\0`!2NH""KL($.L*"$_JAG!!\0`)N0=!ZI8!W>D(9T#J`0M!Z@,,
MS>D,O`WU+GQ/\``*S>D0B=SI``'11H;J"P9/ZDH3#_+H"]OI`*M#ZMAC`9,-
M]3!\$.L*`$'K"P&+1MWI#A(&FG%`@A@.1D_J2!$`D4OQ``.21D_JV&(:ZP8`
MW>D`JT+J21)#\0`!2NH""JL($.L*!D_JA'!!\0`'J0=!ZI0!#_*("]OI`*M`
MZ@$$0>H#!=SI``$-]3)\(D8K1A#K"@#=Z0Q%0>L+`<WI!B-40,WI#F>+1MWI
M$!((F@`G84![`8(80^K68PQ&`9-/ZD81`)%+\0`#DD;R#AKK!`#=Z0"K0NI'
M$D/Q``%/ZID#2NH""@`B$.L*!$_JB'`*X`"_K_,`@-R\&X\`````UL%BR@``
M``!!\0`%3^J)<4'JF`'-Z1!%0.H!"4'J`PH`)0`C2$911MWI!HD/\C`[V^D`
MJ\WI`"-K`0&3B.H`"-SI`"/-Z0@!$NL*`D/K"P.21MWI#A(,FIM&@>H(`0&;
M&NL"`D/JU&.(1@&33^I$$0"12_$``Y)&X@X:ZP@`W>D`JT+J11)#\0`!2NH"
M"KL($.L*"$_JAG!!\0`)N0=!ZI8!W>D(9T#J`0M!Z@,,S>D,O`WU-'Q/\``*
MS>D4B=SI``'11H;J"P9/ZDH3#_*0*]OI`*M#ZMAC`9,-]39\$.L*`$'K"P&+
M1MWI$!(&FG%`@A@.1D_J2!$`D4OQ``.21D_JV&(:ZP8`W>D`JT+J21)#\0`!
M2NH""JL($.L*!D_JA'!!\0`'J0=!ZI0!#_(P*]OI`*M`Z@$$0>H#!=SI``$-
M]3A\(D8K1A#K"@#=Z0Q%0>L+`<WI#B-40,WI!F>+1MWI%!((F@`G84![`8(8
M0^K68PQ&`9-/ZD81`)%+\0`#DD;R#AKK!`#=Z0"K0NI'$D/Q``%/ZID#2NH"
M"D_P``L0ZPH$3^J(<$'Q``5/ZHEQ0>J8`:)&0>H#"4#J`0C-Z1!%W>D.14%&
M2D;-Z0@23$!CH]/I`"/<Z0`!3^I+&4GJVFE/ZDH8@!A/ZH=U64'-Z0`!W>D&
M$D7JE@4,F@WU.GQA0`Q&W>D``<WX`)"`&$'Q``$"&4'Q``/-Z08C3^K;8P&3
MW>D`([0'N0@`(T+J"`+=Z0:)1>H!"=SI`&<8ZP((0D9$Z@4(S>D`(TQ&`"(`
M(\WI!B-#1MWI`(G-Z0PT2D92`0>2W>D($EE`8D`'FSREU>D`10A&0^K88Q%&
MI!E"1MWI$(DF1M0.B.H`"(GJ`0D.FMWI``'-Z1")%NL""!":!Y-#`0:31.I!
M%!CK`@A/ZHMQW>D&(T'JF@%/ZHIP(D-`Z@$*&ID8ZP((W>D"(P`C$NL(`MWI
M%HG!Z0`CW>D`-!/K"`-$ZPD$F$:A1LWI`(F]G=WI"G@,F_\8&YM(\0`(S>D"
M>-WI$G@<:`B;_QC=Z00C2/$`",WI!GC=Z0)G`"?=Z0")3_``"1+K"@*E0L'I
M!F=/\``#P>D"B1J>W>D&`4_P``'&Z00CQND(`0/1#?4_?;WH\(_\]R#M`+^O
M\P"`UL%BR@`````MZ?A#($M[1``H.-`?2IM8T_@`D+GQ``\ST`-XL_$]!1B_
M`24`*PB_`"6MN=GX`$!\L0=&B$9.1BI&.48@1OSW!NX0N6-=/2L/T%;X!$\`
M+/+1($:]Z/B#!485^`$_`"L8OSTK^=$M&N#G`36FZPD&+$2V$,CX`&`@1KWH
M^(,$1N?G3$;EYP"_3F4!`$P!``#PM8.P%4\%1A5+;$9_1/Y8,V@!DR%&*$;_
M]ZK_L+$12P"8^U@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48H1O_W
ME/\`*.C1`9HS:)I"`=$#L/"]_/>B[+AD`0`8`0``3`$``"WI\$\,1M_X7)&%
ML%9+!4;Y1`IX6?@#8#TJ"+\!-#-H($8#D_SW`NT"J0=&*$;_]VO_@$8`*%30
M_/?X[+A"1])*2P*:6?@#D$_J@@@K>+/Q/0`8OP$@`"L(OP`@.+$H1A#X`3\`
M*QB_/2OYT4`;`C?9^`"@.$3\][;L2O@(```H:]#9^``@:1P"F"MX4O@@`#TK
M&+\`*P-P"=!"'!'X`3L01@`K&+\]*P+X`3OVT0)&/2,#<!3X`3L"^`$_`"OY
MT0`@`YHS:)I"2M$%L+WH\(\(\?\P%/@!.P#X`3\`*_G1[N<B2UGX`Y#9^`"P
MV_@`,(.S6T8`X%!&4_@$+P#Q`0H`*OC1`S"``!E*>D03:+.Y`2,38/SW9NP!
MD/"Q3^J*"%E&0D;\]]CK`9O)^``P"O$!`@`A0_@B$,WX"*"&YP%&6$;\]P[L
M`T;)^```*+%/ZHH([.>:1@@@UN=/\/\PL.?\]^KK3&0!`!@!``!,`0``YF0!
M`#)+,TI[1"WI\$.?L)Q8(V@=DQ"Q`W@&1C.Y'9HC:)I"4=$?L+WH\(/\]Q;L
M!T8`*//0W_B@@/A$.$;\][KL`"@WT,-\T_$N`P?1`WT`*_/0T_$N`P2_0WU;
M0@`K[-``\1,%,$;\]RCL@48H1OSW).Q(1`(P_/?\ZT-&3_#_,@$A`94`EH%&
M_/<V[$E&`JH#(/SWH.P!,$A&!=`&FP/T<$.S]8!/#-#\]YSK2$;\]V#KPN<X
M1OSWK.PP1OSW;.NLY__WGO_QY_SW?NL`O^1B`0`8`0``7A,``#BU!4852Q9*
M>T2<6"!H_/>:["E&`/6D<@,@_/>([`BQ`"`XO2!H_/>.[-#X6#$#]'!#L_6`
M3PG0(&C\]X3LT/A8,0/T<$.S]2!/Z=$H1@(A_/<P[+#Z@/!`"3B]"&(!`"`!
M```MZ?!#K?6`729,@[`F2PWU@%9\1`&M@$8D2.=8!#:)1D#V_W(I1GA$.V@S
M8/SW4NL?2P`H*=U&'N-8JET<:-*Q!D8R1B\A*$;\]_SKJ+$@1OSW1NPS1BI&
M04;\]Q+L#?6`4P0S&F@[:)I"&-$-]8!=`["]Z/"#`"[CT2!&_/<P[$I&04;\
M]R#KZ>?C6!QH($;\]R;L2D9!1OSW%NO?Y_SW].H`OYIA`0`8`0``.A(``"`!
M```0M0A,"$M\1.-8&&C\]P[L!DH'2P=)HEA[1'E$O>@00/SWA+OR8`$`(`$`
M`!P!``!<$0``HA$```U+#DI[1!"U@K"<6"!H_/?RZ__WV?\@:/SW[.L(2P`A
M"$I[1,WI`#$'27I$>43\]X[K`K`0O0"_O&`!`"`!``!.%```GPT``'01```@
M2B%+>D3PM:WU`%W56(>P#?4`4AU,%#(-]8!6*VA\1!`V$V#\]P+K&4M!\@$"
M`2%[1,WI``0#K"!&_/<BZR!&,49/](!2_/>JZ@0>%MM@'/SWU.H'1BBQ,48B
M1OSW6NH`(SM5#?4`4SA&%#,::"MHFD(%T0WU`%T'L/"]`"?QY_SW9NIP8`$`
M&`$``%H1```\$0``__>TORWI\$^M]8%=W_AT@8.P74L$1OA$#?6!4EM(!#)8
M^`,P#?$H"0U&>$2I\0@!!9,;:!-@__<I_2\A!D8@1OSWPNJ8L5)((49X1/_W
MFOT@1@WU@5,$,QIH!9L;:)I"0/"-@`WU@5T#L+WH\(\@1OSWGNI'27E$@D8H
M1OSW".L'1@`HW]!$2]_X$+%[1`:30TO[1'M$!Y,[>``K2]`NL3E&,$;\][SI
M`"A*T#A&_/>`ZD(>NQBZ7"\J!M$`(1EP`3@3^`$M+RKYT`KQ`0,81+#U@%^W
MVJGQ!`4R2@$A6T9Z1`"7`9(H1D_T@%("E/SW?NHM2UCX`W`X:/SW#.LI1@#U
MI'(#(/SWXNI(N3AH_/<"Z]#X6#$#]'!#L_4`3QS0(DD`('E$_/>TZ@=&`"^*
MT#MX`"NST6ZQ!IDP1OSW<.G0N1M)`"!Y1/SWHNH'1@`O[M%XYP>?`2"WYP$A
M*$;\]Y+J`"C<T1-(*49X1/_W"OTH1OSW2NILYP:?`2"EY_SWGND`O\I?`0`8
M`0``PA```*X0``"2$```7!```'H0``!4$```-!```"`!``#D#P``P@\``(X/
M```#>#NQ0APO*PB_$$82^`$[`"OXT7!'`+\XM?BQ!7@$1N6Q_/?JZ0$X(AB4
M0@S2(UPO*S;14QX"X!%X+RDQT:-"&D8#\?\S]]&40A#1+RT%T!I(O>@X0'A$
M_/?XN0(@_/>HZ1"Q+B("@#B]`"`XO0$Z`^`1>"\I!-$:1I1"`O'_,_?3$AN3
M'+/U@%_NV`Q((48!,D_T@%-X1`1&_/<NZ2!&.+U3'@+@$7@O*>#0G$(:1@/Q
M_S/WTY1"R-#8YP8/```Z7P$`+>GP08RP1DP"K49/?$1&3@PT?T3?^!2!#\SX
M1+]9`:X/Q0_,U_@`P`_%)&A`2,WX+,!X1"R`__<S_#Y(>$3_]R_\/4AX1/_W
M*_P\2'A$__<G_#M(>$3_]R/\.DAX1/_W'_PY2'A$__<;_#A(>$3_]Q?\0$;_
M]Q3\-4AX1/_W$/PT2'A$__<,_#-(,49X1/_WO_L8L0%&0$;_]S;\+T@Q1GA$
M__>U^R"Q`48M2'A$__<K_"Q(,49X1/_WJON(L0%&*4AX1/_W(/PH22E(>41X
M1/_W&OP+FCMHFD(>T0RPO>CP@21(,49X1/_WDOMXN2))"B(-\1D`>43\][#I
M`"CCT1Y(#?$C`7A$__?^^]SG`48;2'A$__?X^];G_/>2Z`"_U`T``%)=`0`8
M`0``T@X``&H.``!L#@``;`X``'`.``!P#@``>`X```P.``!T#@``?@X``/H-
M``!X#@``>`X``(`.``""#@``K@T``.`/``#V#0``8@X``&8.``#:#0``S@T`
M`!))$TIY1!-+$+5[1(Q8@K`8:"-H`9-#'`70`9HC:)I"$M$"L!"]#$AI1GA$
M__<N^S"Q`'@P*!B_`"@4OP$@`"`&2WM$&&#HY_SW..C<6P$`&`$``"Y=`0`R
M#0``]EP!``BU^_?V[_OWZ.\`L0!H"+T@2R%*>T0MZ?!!AK"<6`5&'DX$J2-H
M?D0P1@63__?^^BE&$+,#>`=&^['[][SO`+LH1OSWANB`1CA&_/>"Z$!$`C#\
M]UKH$DM/\/\R`I=[1,WI`%,/2P$A>T2`1OSWCNA!1C!&__=6^P/@"TAX1/_W
M4?L%FB-HFD("T0:PO>CP@?OWY.]L6P$`&`$``%X-``!*#```1`P```@-```M
MZ?!/K?4!3=_X5$>1L-_X5)<-]:![?$3?^$PW(AT'D/E$J_'@!0?*!/$0#`B5
MJ_'X!UGX`S`$\2@*J_'L"*OQ_`:'Z`<`!I.\Z`\`!IP/Q0WU`4.<Z`,`/#/4
M^`#@A>@#`)KH!P##^`#@B.@'`#%&W_CX!GA$__>#^B"Q`W@$1@`K0/!;@?_W
M9?\%1@`H`/!<@2A&_/<&Z$```3#[]][O*WB"1H.QW_C(AE1&^$0`DR!&0T9/
M\/\R`2$"-/SW$.@5^`$_`"ORT5OXX`RPL0B<`N!4^`0/B+$Q1O_W4?H%1@`H
M]M`#>``K\]#_]^O[`"COT"A&_/<"Z`1&F+D`)5?X)4``+&O0(W@`*VC0($8!
M-?_WV/L`*/+0($;[]_#O`"CMT`1&($;?^$QV^_>\[]!&?T0%1E!&^_>V[P5$
M!?($12A&^_>,[]_X,#9/\/\R`2%[1,WI`3??^"0VS?@,@'M$`)2"1OOWO.]0
M1D_TX''[]]3O`3`%T?OWKN\":!$J0/"4@M_X_#59^`-P.&C\]SSH448`]:1R
M`R#\]RKH!$8`L]_XX"4!(0>;`"59^`(`W_C8)1MH>D3-^`"@`&C[]\KO#?4!
M0RA&/#,::`:;&VB:0D#PKX(-]0%-$;"]Z/"/`"2@YSAH_/<0Z-#X6#$#]'!#
ML_6`3]31.&C\]P;HT/A@@?OWH.Z`1<O1.&C[]_[OT/A8,</S"`.S]>!_P=$H
M1OOW'N\Q1@5&W_AD!7A$__>H^0`H`/"I@`>;'FC[]V#O`48P1O_W6?P&1@`H
M`/"=@#!&^_<H[P,H!T80V=_X-!4$.#!$>43[]U;N0+D$+P#P^8$W1!?X!3PO
M*P#P\X'_]SK^,+D!1C!&^_?D[@R0`"A^T=_X`!7?^``%>43?^`!U>$3?^/R4
M__?H^7]$^_?P[M_X]#3?^/043_#_,GM$`9/?^.PT>43-^`"@^40#D7M$`2'?
M^-R$^$0"D"A&^_<"[SM&5T::1A3@^_?V[@-H$2L7T?OWS.X!-,WX$(`R1@.4
M2T;-^`2@`2$`EP*0*$;[]^CN3_3@<2A&^_<`[T,<!D;BT+I&4$;[]QKNW_B(
M!"E&>$3_]Z+Y*$;_]Q7^0>?_]Q+^($;[]]SN!48ZYP1&".N$!00]5?@$#W"Q
M,48!-/_W$/D`*/;0`W@`*_/0^_?([@`H[-`%1HWF#2#?^#Q4^_=N[E,C?42"
M1H[F!YL>:%_GJ_$$`V_P$0('DP(D'D8`E$_P_S/[]T3N,48&(@R8^_?$[1OX
M!#P;N7-X0RL`\(6!`"0`(@`C`)0,F*OQR`G[]R[NV:'1Z0`!VJ/3Z0`CR?AX
M0,GI`@&K\9`!#I'7H='I``')Z00CUJ/3Z0`CR>D&`=:AT>D``<GI"",`(@`C
M#Y7)Z0HCR>D,(TOI,@'-^#2P3_0`0@>9#)C[]XCM!!Y`\X*`(D;C%\WI"B-/
M\``,V>D,(]GI"F<91N,`$$::&;Q%S>D(`0B_LD*31@320AQ!\0`#S>D((UI&
M8T;)Z0HCW>D*$MGX>`!.#U</1NK"!MWI"".2&7M!%D8?1LGI#&<`*$_0P/%`
M!@Z;ID('F1A$J+\F1C)&^_=H[=GX>#`S1,GX>#!`*[31!YM(1J0;'D3\]Q#X
M/RPLW:3Q0`@&\8`'*/`_`]WX-+`&\4`.'T2N\4`$J_&0#"!H$#14^`P<9494
M^`@L#/$0#%3X!#QT10_%\=%(1OOW[O\$\4`.OD7FT4_JF!3-^#2P8QRHZX04
M!NN#%C%&2",B1@Z8^_=P[<GX>$!VYP>>Q>?=Z0P+#YW[]U3NV?@H0*OQD`?9
M^#!@@"'$\\4"4QPX*[E4`/.9@/@8P_$X`@`A^_?@[4A&(@Z)^'-@,PZ)^'0@
MJ_$P!XGX=T")^'`P,PPV"HGX<3")^')@(PPD"HGX=3")^'9`^_>B_UOXR,RK
M\40"V?@(8*OQ"`O9^!!`V?@8`$_J'$%1<$_J'&/9^"`0W_CXD0OX/#S6<?E$
MU'+0<]%T@O@#P$_J'"R"^`+`3^H6;(+X!,!/ZA9,-@J"^`7`EG$F#A9R)@PD
M"E9RE'(61@0.%',$#``*5',\1I!S"`X0=`@,"0I0=)%T`>`6^`$_`),@1DM&
M3_#_,@$A`C3[]U;MHT7RT6%(3_#_,F%+`2%X1`*7`Y![1,WX`*`H1@&3`".'
M^"@P6TM[1/OW0.U?Y@>;7V@`+S_T"*XX1OOW&NT#*'_V`JY4200X.$1Y1/OW
M2.P`*`B_/D;WY</Q0`+X&``A^_=&[4A&^_<A_SA&."(`(?OW/NU=YS9(`2$'
MFP`E6?@``!MHS>D`HD1*`&AZ1/OW2.U[Y0>;FWA!*W_T=JX'F]MX0RM_]'&N
M!YL;>4@K?_1LK@>;6WE%*W_T9ZX`E$_P_S,,G&_P.0(@1OOWENP'GB!&*2(R
M3#%&^_<4[#%+?$1/\/\R>T0!DR]+`2$"EBA&S?@`H'M$`Y3[]]CL]^7[]S[L
M`+^)J\WO`````/[<NI@`````=E0R$`````#PX=+#``````$C16<`````%EP!
M`+1:`0`8`0``;`L``$0,``#4"P``N`H``)H+```@`0``*`$``)P+```>"P``
M0@L``(0+``"R"0``8`D```P+``!."0``P@L``/@*``"P"P``L@@``&8)```D
M!P``0@@``,`%``!:!P``+@<``$P&``!R!P``\`0``(P&``"72IA)+>GP3WI$
MA["62P2N`I906`%H`Y`%D=18(&C[]P3M!48@:/OW`.V5^&@P,4:`^&DPC4AX
M1/[WLOX8L0-X,2L`\.F`__>C^B!H^_?L[(=)"R,!(GE$^_<<[``H8]"$2@%I
M>D34^`"@4FC1^!B``2I;W=_X`+)/](!I?TO`\B`)^T0`)GM$`24`DRC@`FC;
M^`@`U/@`H)-H4/@E<`GJ`P.S]8!O"+\1:0S04$8!D?OWNNP!F0(C`"():/OW
MNNO4^`"@`48X1OOW-.L`FUMH`"A`\)2``34!-JM"0/./@%!&^_>B[$%&`",R
M1OOW8.P!1@`HR]%B2M3X`*!Z1%)H41ZQ0A+1`2H0W5Y.`2501GY$`.`@:/OW
MB.Q!1OOW-.MS:`$UJT+UW-3X`*!01OOW?.Q520,C`2)Y1/OWK.L%1FBQ(&C[
M]W#L*VE02AEH>D3[]U[K*VD;:)MH6P)LU"!H^_=B[$I)`R,!(GE$^_>2ZP5&
M>+%'2`*9>$3^]Q'^!D8@:``N3=#[]U#L*VDR1AEH^_<^ZR!H^_=([#]-?40&
M1B!H^_="[#U)`2)Y1/OWG.L[2GI$`48P1OOW*NL@:/OW-.P`(@*9`T8V2(/X
M:2!X1/[WYOT$1NA@F+%/].!Q($;[]ZKK0QP1*!B_`2LNV`.;!9H;:)I")]$'
ML+WH\(\:1G[GJ&C_]PS[!$;H8``HY-$E2'A$^_=ZZT-X`"L_]!6O$>?[]P+L
M(4LJ:7M$FV@0:!EH_O>)_ZWG(&C[]_;K*VD9:/OWC.N*Y_OWPNH820-&&$@B
M1GE$>$2):`EH^_=6Z^Q2`0`8`0``(`$``!X$``"R!0``)%0!``94`0`"5`$`
MC%,!`'A3`0#8!```Q@0``+($``"4`@``[%(!`'8$``"&!```,@(``"X$``!>
M4@$`-%(!``X$```XM05&__<2^0-X!$8[L4(<+RL(OQ1&$O@!.P`K^-'_]QWZ
M`"T8OP`H`-$XO2MX`"O[T`9)($8$(GE$^_=\ZP`H\]$H1KWH.$#^]X2^-`(`
M``5+$+1[1`5,&UD#L1MH7?@$2_OW7[H`O^A/`0`P`0``+>GX0P=&"TZ(1@M-
MD49^1/OWYNE]1'8;MA`)T``D`315^`0[2D9!1CA&F$>F0O;1O>CX@Y).`0"(
M3@$`<$<`OPA`+>D(@+WH`0`"`'!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@`````"5S+R5S````+W!R;V,O<V5L9B]E>&4`
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ
M0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]0
M4D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)
M0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?
M1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)
M4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,
M14%./0``3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E
M<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``%!!5$@`````)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``<&%R;``````N<&%R````
M`"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M
M)74E<P````!!4D=6`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ
M5D524TE/3@`````Q+C`T,0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!54T52
M`````%5315).04U%`````%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE
M8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T
M(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM
M>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U
M=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G
M+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII
M9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@
M,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@
M/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S
M92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL
M96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&
M2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F
M<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@
M/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E
M="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q
M<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E
M860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<
M;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\
M("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U
M;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&
M2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B
M=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER
M95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U
M9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[
M8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG
M+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B
M.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A
M<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F
M:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P
M87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@
M/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I
M<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T
M(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@
M7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7
M<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R
M:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*
M?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES
M<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O
M9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N
M)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D
M9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@
M(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%2
M1T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?
M)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T
M<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*`-QX_W\!````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`+$8``!Q&````0````$````!````RP$```$```#6`0```0```.`!```!````
M+P(```$```"*`P```0```+`#```,````P!(```T````@7P``&0```("M`0`;
M````!````!H```"$K0$`'`````0```#U_O]OM`$```4```"`"0``!@```*`"
M```*````%`4```L````0````%0`````````#````L*X!``(``````@``%```
M`!$````7````P!```!$```#0#P``$@```/`````3````"````!X````(````
M^___;P$```C^__]O<`\``/___V\#````\/__;Y0.``#Z__]O$0``````````
M``````````````````````````````````````````````"(K0$`````````
M``#,$@``S!(``,P2``#,$@``S!(``,P2``#,$@``S!(``,P2``#,$@``S!(`
M`,P2``#,$@``S!(``,P2``#,$@``S!(``,P2``#,$@``S!(``,P2``#,$@``
MS!(``,P2``#,$@``S!(``,P2``#,$@``S!(``,P2``#,$@``S!(``,P2``#,
M$@``S!(``,P2``#,$@``S!(``,P2``#,$@``S!(``,P2``#,$@``S!(``,P2
M``#,$@``S!(``,P2``#,$@``S!(``,P2``#,$@``S!(``,P2``#,$@``S!(`
M`,P2``#,$@``S!(``,P2``#,$@``S!(``,P2``#,$@``'5\`````````````
M````````````````````````````````!+`!``````#A7@```````/$5````
M````````````````````!+`!`/____^,8@``N%\```````!X8```?&```(!B
M``#`7P``B&(```````!L8@``=&(```````"48@``1T-#.B`H1&5B:6%N(#<N
M,BXP+3$X*2`W+C(N,`!'0T,Z("A$96)I86X@-BXT+C`M,3$I(#8N-"XP(#(P
M,3<Q,C`V`$$R````865A8FD``2@````%-RU!``8*!T$(`0D""@02!!,!%`$5
M`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G
M`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````````````
M```````````````````````````````````````+`````0````(```!4`0``
M5`$``!D```````````````$`````````$P````<````"````<`$``'`!```@
M```````````````$`````````"$````'`````@```)`!``"0`0``)```````
M````````!``````````T````]O__;P(```"T`0``M`$``.P````%````````
M``0````$````/@````L````"````H`(``*`"``#@!@``!@````,````$````
M$````$8````#`````@```(`)``"`"0``%`4``````````````0````````!.
M````____;P(```"4#@``E`X``-P````%``````````(````"````6P```/[_
M_V\"````<`\``'`/``!@````!@````,````$`````````&H````)`````@``
M`-`/``#0#P``\`````4`````````!`````@```!S````"0```$(```#`$```
MP!`````"```%````%0````0````(````?`````$````&````P!(``,`2```,
M```````````````$`````````'<````!````!@```,P2``#,$@``(`,`````
M````````!`````0```""`````0````8```#P%0``\!4``#!)````````````
M``@`````````B`````$````&````(%\``"!?```(```````````````$````
M`````(X````!`````@```"A?```H7P``H#\`````````````!`````````"6
M`````0``<((```#(G@``R)X```@````-``````````0`````````H0````$`
M```"````T)X``-">```$```````````````$`````````*L````.`````P``
M`("M`0"`K0``!```````````````!`````0```"W````#P````,```"$K0$`
MA*T```0```````````````0````$````PP````8````#````B*T!`(BM```H
M`0``!@`````````$````"````,P````!`````P```+"N`0"PK@``4`$`````
M````````!`````0```#1`````0````,`````L`$``+```$``````````````
M``0`````````UP````@````#````0+`!`$"P```8$``````````````$````
M`````-P````!````,`````````!`L```0P```````````````0````$```#E
M`````P``<```````````@[```#,```````````````$``````````0````,`
B`````````````+:P``#U```````````````!````````````
